NodeAndContext

Struct NodeAndContext 

pub struct NodeAndContext<SE, PA>
where SE: StorageEngine + Send + Sync + 'static, PA: PolicyAgent + Send + Sync + 'static,
{ pub node: Node<SE, PA>, pub cdata: PA::ContextData, }

Fields

node: Node<SE, PA>cdata: PA::ContextData

Implementations

Source

impl<SE, PA> NodeAndContext<SE, PA>
where SE: StorageEngine + Send + Sync + 'static, PA: PolicyAgent + Send + Sync + 'static,

pub async fn fetch_entities( &self, collection_id: &CollectionId, args: MatchArgs, ) -> Result<Vec<Entity>, RetrievalError>

Fetch a list of entities based on a selection

pub async fn commit_local_trx( &self, trx: &Transaction, ) -> Result<(), MutationError>

Does all the things necessary to commit a local transaction notably, the application of events to Entities works differently versus remote transactions