WeakEntitySet

Struct WeakEntitySet 

pub struct WeakEntitySet(/* private fields */);
A set of entities held weakly

Implementations

Source

impl WeakEntitySet

pub fn get(&self, id: &EntityId) -> Option<Entity>

pub async fn get_or_retrieve<R>( &self, retriever: &R, collection_id: &CollectionId, id: &EntityId, ) -> Result<Option<Entity>, RetrievalError>
where R: Retrieve<Id = EventId, Event = Event> + Send + Sync,

pub async fn get_retrieve_or_create<R>( &self, retriever: &R, collection_id: &CollectionId, id: &EntityId, ) -> Result<Entity, RetrievalError>
where R: Retrieve<Id = EventId, Event = Event> + Send + Sync,

Returns a resident entity, or fetches it from storage, or finally creates if neither of the two are found

pub fn create(&self, collection: CollectionId) -> Entity

Create a brand new entity, and add it to the set

pub async fn with_state<R>( &self, retriever: &R, id: EntityId, collection_id: CollectionId, state: State, ) -> Result<(Option<bool>, Entity), RetrievalError>
where R: Retrieve<Id = EventId, Event = Event>,

Returns a tuple of (changed, entity) changed is Some(true) if the entity was changed, Some(false) if it already exists and the state was not applied None if the entity was not previously on the local node (either in the WeakEntitySet or in storage)