pub struct KeySpec {
pub keyparts: Vec<IndexKeyPart>,
}Fields
keyparts: Vec<IndexKeyPart>Implementations
Sourceimpl KeySpec
impl KeySpec
pub fn new(keyparts: Vec<IndexKeyPart>) -> Self
Sourcepub fn name_with(&self, prefix: &str, delim: &str) -> String
pub fn name_with(&self, prefix: &str, delim: &str) -> String
Simple name generator similar to your existing helper.
Sourcepub fn matches(&self, other: &KeySpec) -> Option<IndexSpecMatch>
pub fn matches(&self, other: &KeySpec) -> Option<IndexSpecMatch>
Checks if this IndexSpec can be satisfied by another IndexSpec Returns Yes if this is a prefix subset of other Returns Inverse if this is a prefix subset of other with all directions flipped Returns No if neither condition is met