Struct Entity

pub struct Entity {
    pub id: ID,
    pub collection: CollectionId,
    pub upstream: Option<Arc<Entity>>,
    /* private fields */
}
An entity represents a unique thing within a collection

Fields

id: IDcollection: CollectionIdupstream: Option<Arc<Entity>>

Implementations

Source

impl Entity

pub fn collection(&self) -> CollectionId

pub fn backends(&self) -> &Backends

pub fn to_state(&self) -> Result<State>

pub fn create(id: ID, collection: CollectionId, backends: Backends) -> Self

pub fn from_state( id: ID, collection: CollectionId, state: &State, ) -> Result<Self, RetrievalError>

pub fn commit(&self) -> Result<Option<Event>>

Collect an event which contains all operations for all backends since the last time they were collected Used for transaction commit. TODO: We need to think about rollbacks

pub fn apply_event(&self, event: &Event) -> Result<()>

pub fn apply_state(&self, state: &State) -> Result<(), RetrievalError>

HACK - we probably shouldn’t be stomping on the backends like this

pub fn snapshot(self: &Arc<Self>) -> Arc<Self>

Create a snapshot of the Entity which is detached from this one, and will not receive the updates this one does