Module node

Structs

MatchArgs
Node
A participant in the Ankurah network, and primary place where queries are initiated
NodeInner
PeerState
WeakNode

Traits

ContextData
Represents the user session - or whatever other context the PolicyAgent Needs to perform it’s evaluation. Just a marker trait for now but maybe we’ll need to add some methods to it in the future.
TNodeErased