pub trait ContextData:
Clone
+ Send
+ Sync
+ 'static { }Expand description
Represents the user session - or whatever other context the PolicyAgent Needs to perform it’s evaluation. Just a marker trait for now but maybe we’ll need to add some methods to it in the future.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.