Reactor

Struct Reactor 

pub struct Reactor<E: AbstractEntity + Filterable + Send + 'static = Entity, Ev: Clone + Send + 'static = Attested<Event>>(/* private fields */);
A Reactor is a collection of subscriptions, which are to be notified of changes to a set of entities

Implementations

Source

impl<E: AbstractEntity + Filterable + Send + 'static, Ev: Clone + Send + 'static> Reactor<E, Ev>

pub fn new() -> Self

pub fn subscribe(&self) -> ReactorSubscription<E, Ev>

Create a new subscription container

pub fn remove_query( &self, subscription_id: ReactorSubscriptionId, query_id: QueryId, ) -> Result<(), SubscriptionError>

Remove a predicate from a subscription

pub fn add_entity_subscriptions( &self, subscription_id: ReactorSubscriptionId, entity_ids: impl IntoIterator<Item = EntityId>, )

Add entity subscriptions to a subscription

pub fn remove_entity_subscriptions( &self, subscription_id: ReactorSubscriptionId, entity_ids: impl IntoIterator<Item = EntityId>, )

Remove entity subscriptions from a subscription

Source

impl<E: AbstractEntity + Filterable + Send + 'static, Ev: Clone + Send + 'static> Reactor<E, Ev>

pub async fn add_query_and_notify<H: PreNotifyHook>( &self, subscription_id: ReactorSubscriptionId, query_id: QueryId, collection_id: CollectionId, selection: Selection, node: &dyn TNodeErased<E>, resultset: EntityResultSet<E>, gap_fetcher: Arc<dyn GapFetcher<E>>, pre_notify_hook: H, ) -> Result<()>

Add a new predicate to a subscription (initial subscription only) Fails if query_id already exists - use update_query for updates

Add a query and send initialization notification (for local subscriptions) Collects ReactorUpdateItems and sends them pre_notify_hook is called before sending notification (e.g., to mark LiveQuery initialized)

pub async fn update_query_and_notify<H: PreNotifyHook>( &self, subscription_id: ReactorSubscriptionId, query_id: QueryId, collection_id: CollectionId, selection: Selection, node: &dyn TNodeErased<E>, version: u32, pre_notify_hook: H, ) -> Result<()>

Update an existing predicate (v>0) and send notifications Does diffing against the current resultset Used by local LiveQuery updates pre_notify_hook is called before sending notification (e.g., to mark LiveQuery initialized)

pub async fn notify_change<C: ChangeNotification<Entity = E, Event = Ev> + Clone>( &self, changes: Vec<C>, )

Notify subscriptions about an entity change

pub fn system_reset(&self)

Notify all subscriptions that their entities have been removed but do not remove the subscriptions

Source

impl Reactor<Entity, Attested<Event>>

pub async fn upsert_query<SE, PA>( &self, subscription_id: ReactorSubscriptionId, query_id: QueryId, collection_id: CollectionId, selection: Selection, node: &Node<SE, PA>, cdata: &PA::ContextData, version: u32, ) -> Result<Vec<Entity>>
where SE: StorageEngine + Send + Sync + 'static, PA: PolicyAgent + Send + Sync + 'static,

Add or update a query for remote subscriptions (server-side) This method is idempotent - it works whether the query exists or not Constructs gap_fetcher internally using the provided Node and ContextData Returns all entities that currently match the selection (for delta generation)