ResultSet

Struct ResultSet 

pub struct ResultSet<R: View>(/* private fields */);
View-typed ResultSet

Implementations

Source

impl<R: View> ResultSet<R>

pub fn by_id(&self, id: &EntityId) -> Option<R>

Source

impl<E: View> ResultSet<E>

pub fn iter(&self) -> ResultSetIter<E>

Methods from Deref<Target = EntityResultSet<Entity>>

pub fn write(&self) -> ResultSetWrite<'_, E>

Begin a write operation for atomic changes to the resultset All mutations happen through the returned write guard A single notification is sent when the guard is dropped (if changes were made)

pub fn read(&self) -> ResultSetRead<'_, E>

Get a read guard for consistent read-only access to the resultset

pub fn set_loaded(&self, loaded: bool)

pub fn is_loaded(&self) -> bool

pub fn clear(&self)

pub fn keys(&self) -> EntityResultSetKeyIterator

Get an iterator over entity IDs without cloning entities

pub fn contains_key(&self, id: &EntityId) -> bool

Check if an entity with the given ID exists

pub fn by_id(&self, id: &EntityId) -> Option<E>

pub fn len(&self) -> usize

pub fn get_limit(&self) -> Option<usize>

Get the current limit for this result set

pub fn wrap<R: View>(&self) -> ResultSet<R>