pub struct ResultSetRead<'a, E: AbstractEntity = Entity> { /* private fields */ }Expand description
A read guard for read-only access to a ResultSet Holds the mutex guard to ensure consistent reads
Implementations
Sourceimpl<'a, E: AbstractEntity> ResultSetRead<'a, E>
impl<'a, E: AbstractEntity> ResultSetRead<'a, E>
Sourcepub fn iter_entities(&self) -> impl Iterator<Item = (EntityId, &E)>
pub fn iter_entities(&self) -> impl Iterator<Item = (EntityId, &E)>
Iterate over all entities Returns an iterator over (entity_id, entity) pairs