pub struct NodeAndContext<SE, PA>{
pub node: Node<SE, PA>,
pub cdata: PA::ContextData,
}Fields
node: Node<SE, PA>cdata: PA::ContextDataImplementations
Sourceimpl<SE, PA> NodeAndContext<SE, PA>
impl<SE, PA> NodeAndContext<SE, PA>
Sourcepub async fn fetch_entities(
&self,
collection_id: &CollectionId,
args: MatchArgs,
) -> Result<Vec<Entity>, RetrievalError>
pub async fn fetch_entities( &self, collection_id: &CollectionId, args: MatchArgs, ) -> Result<Vec<Entity>, RetrievalError>
Fetch a list of entities based on a selection
Sourcepub async fn commit_local_trx(
&self,
trx: &Transaction,
) -> Result<(), MutationError>
pub async fn commit_local_trx( &self, trx: &Transaction, ) -> Result<(), MutationError>
Does all the things necessary to commit a local transaction notably, the application of events to Entities works differently versus remote transactions