pub struct Entity(/* private fields */);Expand description
An entity represents a unique thing within a collection. Entity can only be constructed via a WeakEntitySet which provides duplication guarantees.
Implementations
Sourceimpl Entity
impl Entity
pub fn id(&self) -> EntityId
pub fn collection(&self) -> &CollectionId
pub fn head(&self) -> Clock
Sourcepub fn is_writable(&self) -> bool
pub fn is_writable(&self) -> bool
Check if this entity is writable (i.e., it’s a transaction fork that’s still alive)
pub fn to_state(&self) -> Result<State, StateError>
pub fn to_entity_state(&self) -> Result<EntityState, StateError>
pub fn create(id: EntityId, collection: CollectionId) -> Self
pub fn view<V: View>(&self) -> Option<V>
Sourcepub async fn apply_event<G>(
&self,
getter: &G,
event: &Event,
) -> Result<bool, MutationError>
pub async fn apply_event<G>( &self, getter: &G, event: &Event, ) -> Result<bool, MutationError>
Attempt to apply an event to the entity
pub async fn apply_state<G>( &self, getter: &G, state: &State, ) -> Result<bool, MutationError>
Sourcepub fn snapshot(&self, trx_alive: Arc<AtomicBool>) -> Self
pub fn snapshot(&self, trx_alive: Arc<AtomicBool>) -> Self
Create a snapshot of the Entity which is detached from this one, and will not receive the updates this one does The trx_alive parameter tracks whether the transaction that owns this snapshot is still alive
Sourcepub fn broadcast(&self) -> &Broadcast
pub fn broadcast(&self) -> &Broadcast
Get a reference to the entity’s broadcast for Signal implementations
Sourcepub fn get_backend<P: PropertyBackend>(&self) -> Result<Arc<P>, RetrievalError>
pub fn get_backend<P: PropertyBackend>(&self) -> Result<Arc<P>, RetrievalError>
Get a specific backend, creating it if it doesn’t exist
pub fn values(&self) -> Vec<(String, Option<Value>)>