pub struct EntityLiveQuery(/* private fields */);Expand description
A local subscription that handles both reactor subscription and remote cleanup This is a type-erased version that can be used in the TContext trait
Implementations
Sourceimpl EntityLiveQuery
impl EntityLiveQuery
pub fn new<SE, PA>( node: &Node<SE, PA>, collection_id: CollectionId, args: MatchArgs, cdata: PA::ContextData, ) -> Result<Self, RetrievalError>
pub fn map<R: View>(self) -> LiveQuery<R>
Sourcepub async fn wait_initialized(&self)
pub async fn wait_initialized(&self)
Wait for the LiveQuery to be fully initialized with initial states
pub fn update_selection( &self, new_selection: impl TryInto<Selection, Error = impl Into<RetrievalError>>, ) -> Result<(), RetrievalError>
pub async fn update_selection_wait( &self, new_selection: impl TryInto<Selection, Error = impl Into<RetrievalError>>, ) -> Result<(), RetrievalError>
pub fn error(&self) -> Read<Option<RetrievalError>>
pub fn query_id(&self) -> QueryId
pub fn selection(&self) -> Read<(Selection, u32)>
Sourcepub fn weak(&self) -> WeakEntityLiveQuery
pub fn weak(&self) -> WeakEntityLiveQuery
Create a weak reference to this LiveQuery
Sourcepub fn mark_initialized(&self, version: u32)
pub fn mark_initialized(&self, version: u32)
Mark initialization as complete for a given version