pub struct EntityResultSet<E: AbstractEntity = Entity>(/* private fields */);Implementations
Sourceimpl<E: AbstractEntity> EntityResultSet<E>
impl<E: AbstractEntity> EntityResultSet<E>
pub fn from_vec(entities: Vec<E>, loaded: bool) -> Self
pub fn empty() -> Self
pub fn single(entity: E) -> Self
Sourcepub fn write(&self) -> ResultSetWrite<'_, E>
pub fn write(&self) -> ResultSetWrite<'_, E>
Begin a write operation for atomic changes to the resultset All mutations happen through the returned write guard A single notification is sent when the guard is dropped (if changes were made)
Sourcepub fn read(&self) -> ResultSetRead<'_, E>
pub fn read(&self) -> ResultSetRead<'_, E>
Get a read guard for consistent read-only access to the resultset
pub fn set_loaded(&self, loaded: bool)
pub fn is_loaded(&self) -> bool
pub fn clear(&self)
Sourcepub fn keys(&self) -> EntityResultSetKeyIterator ⓘ
pub fn keys(&self) -> EntityResultSetKeyIterator ⓘ
Get an iterator over entity IDs without cloning entities
Sourcepub fn contains_key(&self, id: &EntityId) -> bool
pub fn contains_key(&self, id: &EntityId) -> bool
Check if an entity with the given ID exists
pub fn by_id(&self, id: &EntityId) -> Option<E>
pub fn len(&self) -> usize