pub struct ResultSetWrite<'a, E: AbstractEntity = Entity> { /* private fields */ }Expand description
A write guard for making atomic changes to a ResultSet Holds the mutex guard to ensure all changes happen atomically Sends a single notification when dropped (if any changes were made)
Implementations
Sourceimpl<'a, E: AbstractEntity> ResultSetWrite<'a, E>
impl<'a, E: AbstractEntity> ResultSetWrite<'a, E>
Sourcepub fn iter_entities(&self) -> impl Iterator<Item = (EntityId, &E)>
pub fn iter_entities(&self) -> impl Iterator<Item = (EntityId, &E)>
Iterate over all entities Returns an iterator over (entity_id, entity) pairs
Sourcepub fn mark_all_dirty(&mut self)
pub fn mark_all_dirty(&mut self)
Mark all entities as dirty for re-evaluation
Sourcepub fn retain_dirty<F>(&mut self, should_retain: F) -> Vec<EntityId>
pub fn retain_dirty<F>(&mut self, should_retain: F) -> Vec<EntityId>
Retain only dirty entities that pass the closure, removing those that don’t
Sourcepub fn replace_all(&mut self, entities: Vec<E>)
pub fn replace_all(&mut self, entities: Vec<E>)
Replace all entities in the result set with proper sorting
Sourcepub fn set_loaded(&mut self, loaded: bool)
pub fn set_loaded(&mut self, loaded: bool)
Set the loaded flag as part of this write transaction. The flag is set while the lock is held, ensuring subscribers see consistent state (both content and loaded flag) when notified.